@@ -5,6 +5,8 @@ import shutil
 import sys
 import tarfile
 
+from ruyaml import YAML
+
 from urllib import request
 from .util import deployable_path
 
@@ -27,7 +29,7 @@ def setup_wizard():
     if os.environ.get('foo'):
         exit(0)
 
-    log('installing dragon v1.6.3')
+    log('installing dragon v1.6.4')
     log('=========================', end='\n\n')
     dragondir = os.path.expandvars('$HOME/.dragon/')
     try:
@@ -38,28 +40,44 @@ def setup_wizard():
     os.chdir(dragondir)
 
     for repo in ('lib', 'include', 'frameworks', 'vendor', 'sdks', 'src'):
+                
         try:
             get_supporting(
                 f'https://api.github.com/repos/DragonBuild/{repo}/releases/latest',
                 repo
             )
-        except: 
+        except Exception as ex: 
+            log(ex)
             log('Potentially ratelimited, attempting fallback by cloning repo (this adds some overhead)')
             os.system(f'git clone https://github.com/dragonbuild/{repo} --depth 1')
 
     log('Deploying internal configuration')
+    os.system(f'rm -rf ./internal')
     shutil.copytree(deployable_path(),
                     dragondir + '/internal')
                     
-    os.mkdir(os.path.expandvars('$HOME/.dragon/toolchain'))
+    try:
+        os.mkdir(os.path.expandvars('$HOME/.dragon/toolchain'))
+    except FileExistsError:
+        pass
     log('Done!')
 
 
 def get_supporting(api: str, destination: str):
     response: dict = json.load(request.urlopen(api))
+    if os.path.exists(f'{destination}/metadata.yml'):
+        with open(f'{destination}/metadata.yml', 'r') as fd:
+            yaml=YAML(typ='safe')  # default, if not specfied, is 'rt' (round-trip)
+            metadata = yaml.load(fd)
+            version = metadata['version']
+            if version == response['tag_name']:
+                log(f'Latest {destination} already installed')
+                return
     tar_url = response['tarball_url']
+    
+    os.system(f'rm -rf ./{destination}')
 
-    log(f'Dowloading supporting {destination} from {tar_url} ...')
+    log(f'Updating supporting {destination} v{response["tag_name"]} from {tar_url} ...')
     tar_bytes = request.urlopen(tar_url).read()
 
     fname = 'tmp.tar.gz'
@@ -69,6 +87,7 @@ def get_supporting(api: str, destination: str):
     tar = tarfile.open(fname)
     extracted_name = tar.members[0].name
 
+
     log(f'Extracting into {os.path.expandvars(dragondir + destination)}')
     tar.extractall()
     os.rename(extracted_name, destination)
